@@ -2,6 +2,8 @@
 #include <config.h>
 #endif
 
+#define _GNU_SOURCE 1
+
 #include "store.h"
 #include "real.h"
 
@@ -9,6 +11,8 @@
 
 int pthread_mutex_destroy(pthread_mutex_t *mutex)
 {
+    init();
+
     struct mutex *n = find_mutex(mutex);
 
     fprintf(stderr, "destroy #%u\n", n->num);
