@@ -2,6 +2,8 @@
 #include <config.h>
 #endif
 
+#define _GNU_SOURCE 1
+
 #include "store.h"
 
 #include "real.h"
@@ -12,6 +14,8 @@
 
 int pthread_mutex_init(pthread_mutex_t *mutex, pthread_mutexattr_t const *attr)
 {
+    init();
+
     struct mutex *n = find_mutex(mutex);
 
     fprintf(stderr, "init #%u\n", n->num);
