@@ -2,6 +2,8 @@
 #include <config.h>
 #endif
 
+#define _GNU_SOURCE 1
+
 #include "store.h"
 #include "real.h"
 
@@ -11,6 +13,8 @@
 
 int pthread_mutex_lock(pthread_mutex_t *mutex)
 {
+    init();
+
     struct thread *t = find_thread(pthread_self());
     struct mutex *n = find_mutex(mutex);
 
