@@ -2,6 +2,8 @@
 #include <config.h>
 #endif
 
+#define _GNU_SOURCE 1
+
 #include "real.h"
 
 #include <dlfcn.h>
@@ -17,10 +19,14 @@ int (*real_cond_init)(pthread_cond_t *, pthread_condattr_t const *);
 int (*real_cond_wait)(pthread_cond_t *, pthread_mutex_t *);
 int (*real_cond_signal)(pthread_cond_t *);
 
-void init(void) __attribute__((constructor));
-
 void init(void)
 {
+    static int initialized = 0;
+    if(initialized)
+        return;
+
+    initialized = 1;
+
     real_create = dlsym(RTLD_NEXT, "pthread_create");
     real_mutex_init = dlsym(RTLD_NEXT, "pthread_mutex_init");
     real_mutex_destroy = dlsym(RTLD_NEXT, "pthread_mutex_destroy");
