@@ -2,9 +2,11 @@
 #include <config.h>
 #endif
 
+#define _GNU_SOURCE 1
+
 #include <pthread.h>
 
-int main()
+int test_main()
 {
     pthread_mutex_t mutex;
 
