@@ -2,6 +2,8 @@
 #include <config.h>
 #endif
 
+#define _GNU_SOURCE 1
+
 #include <pthread.h>
 
 #include <unistd.h>
@@ -16,7 +18,7 @@ void *thread_func(void *p)
     return 0;
 }
 
-int main()
+int test_main()
 {
     pthread_t thread;
     pthread_mutex_t mutex;
