@@ -2,6 +2,8 @@
 #include <config.h>
 #endif
 
+#define _GNU_SOURCE 1
+
 #include "store.h"
 #include "real.h"
 
@@ -54,6 +56,8 @@ int pthread_create(
         void *(*start_routine)(void*),
         void *arg)
 {
+    init();
+
     struct startupinfo sui = { start_routine, arg, {}, {} };
     real_cond_init(&sui.cond, 0);
     real_mutex_init(&sui.mutex, 0);
